from flask import Flask

from flask_sqlalchemy import SQLAlchemy

from config import config_map

db = SQLAlchemy()   # 注意：此时没有把app对象传递进来，db无法获取数据库的配置信息

# 负责创建应用
def create_app(config_name):
    """
    manager.py文件中 app = create_app('development')
    传递参数development，
    形参 config_name 获取到参数
    根据不同参数加载不同的配置信息
    """
    app = Flask(__name__)
    obj = config_map.get(config_name)
    # 加载配置文件
    app.config.from_object(obj)
    db.init_app(app)    # 将获取到config配置信息的app对象传回db=SQLAIchemy()

    # 注册蓝图 初始化以后
    from flask_shop.user import user_bp
    app.register_blueprint(user_bp)
    return app


if __name__ == "__main__":
    app.run()