"""
User视图函数
"""

from flask_shop.user import user_bp

from flask_shop import models
from flask import request
from flask_shop import db
from flask_restful import Resource
from flask_shop.user import user_api
from flask_shop.utils.message import state_message
from flask_shop.utils.tokens import generate_auth_token, verify_auth_token
from flask_shop.utils.tokens import login_required
import re

@user_bp.route('/')
def index():
    return "User Hello"


# 用户注册操作
class User(Resource):
    def get(self):
        pass
    def post(self):
        
        name = request.form.get('name')
        pwd = request.form.get('pwd')
        confirm_pwd = request.form.get('confirm_pwd')
        nick_name = request.form.get('nick_name')
        phone = request.form.get('phone')
        email = request.form.get('email')

        # 验证数据的正确性
        if not all([name, pwd, confirm_pwd]):
            return state_message(10000)
        if len(name) < 2:
            return state_message(10011)
        if len(pwd) < 2:
            return state_message(10012)
        if pwd != confirm_pwd:
            return state_message(10013)
        if not re.match(r"^(13[0-9]|14[5|7]|15[0|1|2|3|5|6|7|8|9]|18[0|1|2|3|5|6|7|8|9])\d{8}$", phone):
            return state_message(10014)
        if not re.match(r"^\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$", email):
            return state_message(10015)
        # 添加数据
        try:
            usr = models.User(name=name, password=pwd, nick_name=nick_name, phone=phone, email=email)
            db.session.add(usr)
            db.session.commit()
            return state_message(200)
        except Exception:
            return state_message(20000)

# 添加类视图和url
user_api.add_resource(User, '/user/') 
            


# 用户端登录操作
@user_bp.route('/login', methods=['POST'])
def login():
    name = request.form.get('name')
    pwd = request.form.get('pwd')

    if not all([name, pwd]):    # 一个为False就都为False
        """如果非True"""
        return state_message(10000)
    if len(name) > 1:
        # 获取数据库的信息
        # usr = db.session.query(models.User).filter_by(name=name).first()
        usr = models.User.query.filter_by(name=name).first()
        if usr:
            if usr.check_password(pwd):     # 返回True或者False
                # 生成token
                token = generate_auth_token(usr.id, 10000000)
                verify_auth_token(token)
                return state_message(200, data={'token': token})

    return {'status':10001,'msg':'用户名或密码错误'}


@user_bp.route('/test/')
@login_required
def test():
    return state_message(200)