'''
1. 加密的数据   uid
2. 算法     python模块
3. 秘钥     flask_app SECRET_KEY
'''

# 导入加密算法模块
from itsdangerous import TimedJSONWebSignatureSerializer as Serializer
from flask import current_app, request
from flask_shop.models import User
import functools
from flask_shop.utils.message import state_message


# 生成token方法
def generate_auth_token(uid, expiration):
    """uid:要加密的数据     expiration 有效期以毫秒为单位"""
    # 创建加密对象
    s = Serializer(current_app.config["SECRET_KEY"], expires_in=expiration)

    # 生成token
    return s.dumps({'id': uid}).decode()

# 解密token的方法
def verify_auth_token(token_str):
    # 创建解密对象
    s = Serializer(current_app.config["SECRET_KEY"])
    try:
        # 解密
        data = s.loads(token_str)
    except Exception:
        return None

    # 查询数据库
    usr = User.query.filter_by(id=data['id']).first()
    return usr


# 登录验证装饰器
def login_required(view_func):
    functools.wraps(view_func)
    def verify_token(*arg, **kwargs):
        try:
            # 获取请求头中的token
            token = request.headers['token']
        except Exception:
            return state_message(10016)

        # 创建解密对象
        s = Serializer(current_app.config["SECRET_KEY"])
        try:
            data = s.loads(token)

        except Exception:
            return state_message(10017)
        
        return view_func(*arg, **kwargs)

    return verify_token